@@ -47,6 +47,9 @@ def get_list(query_dc, key):
         ret = query_dc.get(key)
     else:
         raise TypeError('query_dc类型不明!')
+
+    if isinstance(ret, str):
+        ret = [ret]
     return ret
 
 
@@ -316,6 +319,10 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
         if only_get_distinct_field:
             distinct_field_ls = self.get_distinct_field_ls()
             assert distinct_field_ls, '指定了only_get_distinct_field的同时必须指定distinct_field_ls!'
+
+            if isinstance(distinct_field_ls, str):
+                distinct_field_ls = [distinct_field_ls]
+
             ret = get_base_serializer(self.queryset, distinct_field_ls)
             return ret
 
@@ -324,18 +331,18 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
 
     def get_only_get_distinct_field(self):
         key = 'only_get_distinct_field'
-        value = self._get_key_from_query_dc_or_self(key)
+        value = self.get_key_from_query_dc_or_self(key)
         ret = pure.convert_query_parameter_to_bool(value)
         return ret
 
     def get_distinct_field_ls(self):
         key = 'distinct_field_ls'
-        ret = self._get_key_from_query_dc_or_self(key)
+        ret = self.get_key_from_query_dc_or_self(key, get_type='list')
         return ret
 
     def get_base_fields(self):
         key = 'base_fields'
-        ret = self._get_key_from_query_dc_or_self(key)
+        ret = self.get_key_from_query_dc_or_self(key, get_type='list')
         return ret
 
     def get_retrieve_ret(self, request: Request, *args, **kwargs):
@@ -516,45 +523,17 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
         ret = self._conv_data_format(resp, page_dc)
         return ret
 
-    def _conv_data_format(self, data: (dict, Response), page_dc):
-        """
-        调整为cnki标准格式
-        """
-
-        # if isinstance(data, list):
-        #     page_dc = {
-        #         'count_items': len(data),
-        #         'total_pages': 1,
-        #         'page_size': len(data),
-        #         'p': 1,
-        #     }
-        #     results = data
-        # else:
-        #     if isinstance(data, Response):
-        #         data = data.data
-        #
-        #     # 分页信息
-        #     count = data.get('count')
-        #     page_size = self.get_request_data().get('page_size', self.pagination_class.page_size)
-        #     p = self.get_request_data().get('p', 1)
-        #     total = math.ceil(count / int(page_size))
-        #
-        #     page_dc = {
-        #         'count_items': count,
-        #         'total_pages': total,
-        #         'page_size': page_size,
-        #         'p': p,
-        #     }
-        #
-        #     results = data.get('results')
-
+    def conv_data_format(self, data: (dict, Response), page_dc):
         ret = {
             'page_dc': page_dc,
             'data': data,
         }
         return ret
 
-    def _get_key_from_query_dc_or_self(self, key):
+    def _conv_data_format(self, *args, **kwargs):
+        return self.conv_data_format(*args, **kwargs)
+
+    def get_key_from_query_dc_or_self(self, key, get_type=None):
         """
         优先检索query_dc是否有key, 其次检索self是否有key这个属性
         :param key: 变量名
@@ -562,14 +541,24 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
         """
 
         query_dc = self.get_request_data()
-        data = query_dc.get(key)
 
+        if get_type == 'list':
+            data = get_list(query_dc, key)
+        elif get_type == 'bool':
+            data = pure.convert_query_parameter_to_bool(query_dc.get(key))
+        else:
+            data = query_dc.get(key)
+
+        # 让request携带的数据可以覆盖自身的key值
         ret_0 = getattr(self, key) if hasattr(self, key) else None
         ret_1 = data if data else None
 
         ret = ret_1 or ret_0
         return ret
 
+    def _get_key_from_query_dc_or_self(self, *args, **kwargs):
+        return self.get_key_from_query_dc_or_self(*args, **kwargs)
+
 
 class BaseList(BaseListView):     # 向下兼容, 返回格式调整, 重写_conv_data_format.
     def _conv_data_format(self, data: (dict, Response)):
